#Calculator

Create instances of calculator as a class in python.

###Functions included:

- **add** - sums calculator memory with provided value.
- **minus** - subtracts the entered value from calculator memory.
- **multiply** - multiplies calculator memory by the input value.
- **divide** - devides the calculator memory by the input value.
- **root** - takes _n_ root from the calculator memory value (square root is taken when no input given).
- **reset** - Resets calculator instance memory to zero.

Each function adjusts the calculator memory, as well as returns the new value.

###Installation

> pip install calculator_rm==0.0.3

###Usage

```
from calculator_rm import calculator

calc_obj = calculator.Calculator() # creates an object instance

calc_obj.add(1) # adds 1 to the instance
calc_obj.minus(2) # subtracts 2 from the instance
calc_obj.multiply(3) # multiplies the instnace by 3
calc_obj.divide(4) # divides the instnace by 4
calc_obj.root() # returns square root of the instance
calc_obj.root(5) # returns root 5 of the instance
calc.obj.reset() # resets instance back to zero.

```
